==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/AbsolutePanelBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PanelBridge } from "./PanelBridge";
import { INativeUIAbsolutePanelBridge_$type } from "./INativeUIAbsolutePanelBridge";
import { markType } from "./type";
import { stringReplace } from "./string";
/**
 * @hidden
 */
export let AbsolutePanelBridge = /*@__PURE__*/ (() => {
    class AbsolutePanelBridge extends PanelBridge {
        constructor() {
            super();
        }
        addHandler(a, b, c, d) {
        }
        getX(a, b) {
            let c = b.v.getStyleProperty("left");
            stringReplace(c, "px", "");
            let d = parseFloat(c);
            return d;
        }
        getY(a, b) {
            let c = b.v.getStyleProperty("top");
            stringReplace(c, "px", "");
            let d = parseFloat(c);
            return d;
        }
        getValue(a, b) {
            switch (b) {
            }
            return null;
        }
        removeHandler(a, b, c, d) {
        }
        setX(a, b, c) {
            b.v.setStyleProperty("left", c.toString() + "px");
        }
        setY(a, b, c) {
            b.v.setStyleProperty("top", c.toString() + "px");
        }
        setValue(a, b, c) {
            switch (b) {
            }
        }
        getChildAt(a, b) {
            return this.c.apply(this, arguments);
        }
        removeChildAt(a, b) {
            this.h.apply(this, arguments);
        }
        addChild(a, b) {
            this.f.apply(this, arguments);
        }
        removeChild(a, b) {
            this.g.apply(this, arguments);
        }
        getChildrenCount(a) {
            return this.e.apply(this, arguments);
        }
    }
    AbsolutePanelBridge.$t = /*@__PURE__*/ markType(AbsolutePanelBridge, 'AbsolutePanelBridge', PanelBridge.$, [INativeUIAbsolutePanelBridge_$type]);
    return AbsolutePanelBridge;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AbsolutePanelBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PanelBridge } from "./PanelBridge";
import { INativeUIAbsolutePanelBridge_$type } from "./INativeUIAbsolutePanelBridge";
import { markType } from "./type";
import { stringReplace } from "./string";
/**
 * @hidden
 */
export let AbsolutePanelBridge = /*@__PURE__*/ (() => {
    class AbsolutePanelBridge extends PanelBridge {
        constructor() {
            super();
        }
        addHandler(a, b, c, d) {
        }
        getX(a, b) {
            let c = b.x.getStyleProperty("left");
            stringReplace(c, "px", "");
            let d = parseFloat(c);
            return d;
        }
        getY(a, b) {
            let c = b.x.getStyleProperty("top");
            stringReplace(c, "px", "");
            let d = parseFloat(c);
            return d;
        }
        getValue(a, b) {
            switch (b) {
            }
            return null;
        }
        removeHandler(a, b, c, d) {
        }
        setX(a, b, c) {
            b.x.setStyleProperty("position", "absolute");
            b.x.setStyleProperty("left", c.toString() + "px");
        }
        setY(a, b, c) {
            b.x.setStyleProperty("position", "absolute");
            b.x.setStyleProperty("top", c.toString() + "px");
        }
        setValue(a, b, c) {
            switch (b) {
            }
        }
        getChildAt(a, b) {
            return this.c.apply(this, arguments);
        }
        removeChildAt(a, b) {
            this.i.apply(this, arguments);
        }
        addChild(a, b) {
            this.f.apply(this, arguments);
        }
        insertChild(a, b, c) {
            this.g.apply(this, arguments);
        }
        removeChild(a, b) {
            this.h.apply(this, arguments);
        }
        getChildrenCount(a) {
            return this.e.apply(this, arguments);
        }
    }
    AbsolutePanelBridge.$t = /*@__PURE__*/ markType(AbsolutePanelBridge, 'AbsolutePanelBridge', PanelBridge.$, [INativeUIAbsolutePanelBridge_$type]);
    return AbsolutePanelBridge;
})();
